@@ -49,12 +49,15 @@ object InsertShuffleNodeBeforeJoin extends Rule[SparkPlan] {
     }
   }
 
+  // SPARK-33832 (Spark 3.3) moves the rule OptimizeSkewedJoin from queryStageOptimizerRules
+  // to queryStagePreparationRules, injecting shuffle after OptimizeSkewedJoin may produce
+  // invalid query plan.
   private def insertShuffleBeforeJoin(plan: SparkPlan): SparkPlan = plan transformUp {
-    case smj @ SortMergeJoinExec(_, _, _, _, l, r, _) =>
+    case smj @ SortMergeJoinExec(_, _, _, _, l, r, isSkewJoin) if !isSkewJoin =>
       smj.withNewChildren(checkAndInsertShuffle(smj.requiredChildDistribution.head, l) ::
         checkAndInsertShuffle(smj.requiredChildDistribution(1), r) :: Nil)
 
-    case shj: ShuffledHashJoinExec =>
+    case shj: ShuffledHashJoinExec if !shj.isSkewJoin =>
       if (!shj.left.isInstanceOf[Exchange] && !shj.right.isInstanceOf[Exchange]) {
         shj.withNewChildren(withShuffleExec(shj.requiredChildDistribution.head, shj.left) ::
           withShuffleExec(shj.requiredChildDistribution(1), shj.right) :: Nil)
