@@ -24,6 +24,7 @@ import scala.util.Try
 import org.apache.kyuubi.plugin.spark.authz.AccessControlException
 import org.apache.kyuubi.plugin.spark.authz.RangerTestNamespace._
 import org.apache.kyuubi.plugin.spark.authz.RangerTestUsers._
+import org.apache.kyuubi.plugin.spark.authz.V2JdbcTableCatalogPrivilegesBuilderSuite._
 import org.apache.kyuubi.plugin.spark.authz.util.AuthZUtils._
 
 /**
@@ -44,27 +45,23 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   val jdbcUrl: String = s"$dbUrl;create=true"
 
   override def beforeAll(): Unit = {
-    if (isSparkV31OrGreater) {
-      spark.conf.set(
-        s"spark.sql.catalog.$catalogV2",
-        "org.apache.spark.sql.execution.datasources.v2.jdbc.JDBCTableCatalog")
-      spark.conf.set(s"spark.sql.catalog.$catalogV2.url", jdbcUrl)
-      spark.conf.set(
-        s"spark.sql.catalog.$catalogV2.driver",
-        "org.apache.derby.jdbc.AutoloadedDriver")
+    spark.conf.set(s"spark.sql.catalog.$catalogV2", v2JdbcTableCatalogClassName)
+    spark.conf.set(s"spark.sql.catalog.$catalogV2.url", jdbcUrl)
+    spark.conf.set(
+      s"spark.sql.catalog.$catalogV2.driver",
+      "org.apache.derby.jdbc.AutoloadedDriver")
 
-      super.beforeAll()
+    super.beforeAll()
 
-      doAs(admin, sql(s"CREATE DATABASE IF NOT EXISTS $catalogV2.$namespace1"))
-      doAs(
-        admin,
-        sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$table1" +
-          " (id int, name string, city string)"))
-      doAs(
-        admin,
-        sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$outputTable1" +
-          " (id int, name string, city string)"))
-    }
+    doAs(admin, sql(s"CREATE DATABASE IF NOT EXISTS $catalogV2.$namespace1"))
+    doAs(
+      admin,
+      sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$table1" +
+        " (id int, name string, city string)"))
+    doAs(
+      admin,
+      sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$outputTable1" +
+        " (id int, name string, city string)"))
   }
 
   override def afterAll(): Unit = {
@@ -79,8 +76,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] CREATE DATABASE") {
-    assume(isSparkV31OrGreater)
-
     // create database
     val e1 = intercept[AccessControlException](
       doAs(someone, sql(s"CREATE DATABASE IF NOT EXISTS $catalogV2.$namespace2").explain()))
@@ -89,8 +84,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] DROP DATABASE") {
-    assume(isSparkV31OrGreater)
-
     // create database
     val e1 = intercept[AccessControlException](
       doAs(someone, sql(s"DROP DATABASE IF EXISTS $catalogV2.$namespace2").explain()))
@@ -99,8 +92,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] SELECT TABLE") {
-    assume(isSparkV31OrGreater)
-
     // select
     val e1 = intercept[AccessControlException](
       doAs(someone, sql(s"select city, id from $catalogV2.$namespace1.$table1").explain()))
@@ -109,7 +100,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #4255] DESCRIBE TABLE") {
-    assume(isSparkV31OrGreater)
     val e1 = intercept[AccessControlException](
       doAs(someone, sql(s"DESCRIBE TABLE $catalogV2.$namespace1.$table1").explain()))
     assert(e1.getMessage.contains(s"does not have [select] privilege" +
@@ -117,27 +107,26 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] CREATE TABLE") {
-    assume(isSparkV31OrGreater)
+    withSingleCallEnabled {
+      // CreateTable
+      val e2 = intercept[AccessControlException](
+        doAs(someone, sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$table2")))
+      assert(e2.getMessage.contains(s"does not have [create] privilege" +
+        s" on [$namespace1/$table2]"))
 
-    // CreateTable
-    val e2 = intercept[AccessControlException](
-      doAs(someone, sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$table2")))
-    assert(e2.getMessage.contains(s"does not have [create] privilege" +
-      s" on [$namespace1/$table2]"))
+      // CreateTableAsSelect
 
-    // CreateTableAsSelect
-    val e21 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$table2" +
-          s" AS select * from $catalogV2.$namespace1.$table1")))
-    assert(e21.getMessage.contains(s"does not have [select] privilege" +
-      s" on [$namespace1/$table1/id]"))
+      val e21 = intercept[AccessControlException](
+        doAs(
+          someone,
+          sql(s"CREATE TABLE IF NOT EXISTS $catalogV2.$namespace1.$table2" +
+            s" AS select * from $catalogV2.$namespace1.$table1")))
+      assert(e21.getMessage.contains(s"does not have [select] privilege" +
+        s" on [$namespace1/$table1/city,$namespace1/$table1/id,$namespace1/$table1/name]"))
+    }
   }
 
   test("[KYUUBI #3424] DROP TABLE") {
-    assume(isSparkV31OrGreater)
-
     // DropTable
     val e3 = intercept[AccessControlException](
       doAs(someone, sql(s"DROP TABLE $catalogV2.$namespace1.$table1")))
@@ -146,80 +135,79 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] INSERT TABLE") {
-    assume(isSparkV31OrGreater)
-
     // AppendData: Insert Using a VALUES Clause
-    val e4 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(s"INSERT INTO $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
-          s" VALUES (1, 'bowenliang123', 'Guangzhou')")))
-    assert(e4.getMessage.contains(s"does not have [update] privilege" +
-      s" on [$namespace1/$outputTable1]"))
+    withSingleCallEnabled {
 
-    // AppendData: Insert Using a TABLE Statement
-    val e42 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(s"INSERT INTO $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
-          s" TABLE $catalogV2.$namespace1.$table1")))
-    assert(e42.getMessage.contains(s"does not have [select] privilege" +
-      s" on [$namespace1/$table1/id]"))
+      val e4 = intercept[AccessControlException](
+        doAs(
+          someone,
+          sql(s"INSERT INTO $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
+            s" VALUES (1, 'bowenliang123', 'Guangzhou')")))
+      assert(e4.getMessage.contains(s"does not have [update] privilege" +
+        s" on [$namespace1/$outputTable1]"))
 
-    // AppendData: Insert Using a SELECT Statement
-    val e43 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(s"INSERT INTO $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
-          s" SELECT * from $catalogV2.$namespace1.$table1")))
-    assert(e43.getMessage.contains(s"does not have [select] privilege" +
-      s" on [$namespace1/$table1/id]"))
+      // AppendData: Insert Using a TABLE Statement
+      val e42 = intercept[AccessControlException](
+        doAs(
+          someone,
+          sql(s"INSERT INTO $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
+            s" TABLE $catalogV2.$namespace1.$table1")))
+      assert(e42.getMessage.contains(s"does not have [select] privilege" +
+        s" on [$namespace1/$table1/city,$namespace1/$table1/id,$namespace1/$table1/name]"))
 
-    // OverwriteByExpression: Insert Overwrite
-    val e44 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(s"INSERT OVERWRITE $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
-          s" VALUES (1, 'bowenliang123', 'Guangzhou')")))
-    assert(e44.getMessage.contains(s"does not have [update] privilege" +
-      s" on [$namespace1/$outputTable1]"))
+      // AppendData: Insert Using a SELECT Statement
+      val e43 = intercept[AccessControlException](
+        doAs(
+          someone,
+          sql(s"INSERT INTO $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
+            s" SELECT * from $catalogV2.$namespace1.$table1")))
+      assert(e43.getMessage.contains(s"does not have [select] privilege" +
+        s" on [$namespace1/$table1/city,$namespace1/$table1/id,$namespace1/$table1/name]"))
+
+      // OverwriteByExpression: Insert Overwrite
+      val e44 = intercept[AccessControlException](
+        doAs(
+          someone,
+          sql(s"INSERT OVERWRITE $catalogV2.$namespace1.$outputTable1 (id, name, city)" +
+            s" VALUES (1, 'bowenliang123', 'Guangzhou')")))
+      assert(e44.getMessage.contains(s"does not have [update] privilege" +
+        s" on [$namespace1/$outputTable1]"))
+    }
   }
 
   test("[KYUUBI #3424] MERGE INTO") {
-    assume(isSparkV31OrGreater)
-
-    val mergeIntoSql =
-      s"""
-         |MERGE INTO $catalogV2.$namespace1.$outputTable1 AS target
-         |USING $catalogV2.$namespace1.$table1  AS source
-         |ON target.id = source.id
-         |WHEN MATCHED AND (target.name='delete') THEN DELETE
-         |WHEN MATCHED AND (target.name='update') THEN UPDATE SET target.city = source.city
+    withSingleCallEnabled {
+      val mergeIntoSql =
+        s"""
+           |MERGE INTO $catalogV2.$namespace1.$outputTable1 AS target
+           |USING $catalogV2.$namespace1.$table1  AS source
+           |ON target.id = source.id
+           |WHEN MATCHED AND (target.name='delete') THEN DELETE
+           |WHEN MATCHED AND (target.name='update') THEN UPDATE SET target.city = source.city
       """.stripMargin
 
-    // MergeIntoTable:  Using a MERGE INTO Statement
-    val e1 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(mergeIntoSql)))
-    assert(e1.getMessage.contains(s"does not have [select] privilege" +
-      s" on [$namespace1/$table1/id]"))
-
-    withSingleCallEnabled {
-      val e2 = intercept[AccessControlException](
+      // MergeIntoTable:  Using a MERGE INTO Statement
+      val e1 = intercept[AccessControlException](
         doAs(
           someone,
           sql(mergeIntoSql)))
-      assert(e2.getMessage.contains(s"does not have" +
-        s" [select] privilege" +
-        s" on [$namespace1/$table1/id,$namespace1/table1/name,$namespace1/$table1/city]," +
-        s" [update] privilege on [$namespace1/$outputTable1]"))
+      assert(e1.getMessage.contains(s"does not have [select] privilege" +
+        s" on [$namespace1/$table1/city,$namespace1/$table1/id,$namespace1/$table1/name]"))
+
+      withSingleCallEnabled {
+        val e2 = intercept[AccessControlException](
+          doAs(
+            someone,
+            sql(mergeIntoSql)))
+        assert(e2.getMessage.contains(s"does not have" +
+          s" [select] privilege" +
+          s" on [$namespace1/$table1/city,$namespace1/table1/id,$namespace1/$table1/name]," +
+          s" [update] privilege on [$namespace1/$outputTable1]"))
+      }
     }
   }
 
   test("[KYUUBI #3424] UPDATE TABLE") {
-    assume(isSparkV31OrGreater)
-
     // UpdateTable
     val e5 = intercept[AccessControlException](
       doAs(
@@ -231,8 +219,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] DELETE FROM TABLE") {
-    assume(isSparkV31OrGreater)
-
     // DeleteFromTable
     val e6 = intercept[AccessControlException](
       doAs(someone, sql(s"DELETE FROM $catalogV2.$namespace1.$table1 WHERE id=1")))
@@ -241,20 +227,15 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] CACHE TABLE") {
-    assume(isSparkV31OrGreater)
-
     // CacheTable
-    val e7 = intercept[AccessControlException](
-      doAs(
-        someone,
-        sql(s"CACHE TABLE $cacheTable1" +
-          s" AS select * from $catalogV2.$namespace1.$table1")))
-    if (isSparkV32OrGreater) {
+    withSingleCallEnabled {
+      val e7 = intercept[AccessControlException](
+        doAs(
+          someone,
+          sql(s"CACHE TABLE $cacheTable1" +
+            s" AS select * from $catalogV2.$namespace1.$table1")))
       assert(e7.getMessage.contains(s"does not have [select] privilege" +
-        s" on [$namespace1/$table1/id]"))
-    } else {
-      assert(e7.getMessage.contains(s"does not have [select] privilege" +
-        s" on [$catalogV2.$namespace1/$table1]"))
+        s" on [$namespace1/$table1/city,$namespace1/$table1/id,$namespace1/$table1/name]"))
     }
   }
 
@@ -281,8 +262,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] ALTER TABLE") {
-    assume(isSparkV31OrGreater)
-
     // AddColumns
     val e61 = intercept[AccessControlException](
       doAs(
@@ -318,8 +297,6 @@ class V2JdbcTableCatalogRangerSparkExtensionSuite extends RangerSparkExtensionSu
   }
 
   test("[KYUUBI #3424] COMMENT ON") {
-    assume(isSparkV31OrGreater)
-
     // CommentOnNamespace
     val e1 = intercept[AccessControlException](
       doAs(
