@@ -81,10 +81,16 @@ class FlinkSQLSessionManager(engineContext: DefaultContext)
   }
 
   override def closeSession(sessionHandle: SessionHandle): Unit = {
-    try {
-      super.getSessionOption(sessionHandle).foreach { s =>
-        sessionManager.closeSession(s.asInstanceOf[FlinkSessionImpl].fSession.getSessionHandle)
+    super.getSessionOption(sessionHandle).foreach { s =>
+      val internalSessionHandle = s.asInstanceOf[FlinkSessionImpl].fSession.getSessionHandle
+      try {
+        sessionManager.closeSession(internalSessionHandle)
+      } catch {
+        case t: Throwable =>
+          warn(s"Error closing flink internal session $internalSessionHandle", t)
       }
+    }
+    try {
       super.closeSession(sessionHandle)
     } catch {
       case t: Throwable =>
