@@ -16,8 +16,6 @@
  */
 package org.apache.kyuubi.engine.jdbc.operation
 
-import org.apache.hive.service.rpc.thrift.{TFetchResultsResp, TGetResultSetMetadataResp, TRowSet}
-
 import org.apache.kyuubi.{KyuubiSQLException, Utils}
 import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.engine.jdbc.dialect.{JdbcDialect, JdbcDialects}
@@ -25,6 +23,7 @@ import org.apache.kyuubi.engine.jdbc.schema.{Row, Schema}
 import org.apache.kyuubi.operation.{AbstractOperation, FetchIterator, OperationState}
 import org.apache.kyuubi.operation.FetchOrientation.{FETCH_FIRST, FETCH_NEXT, FETCH_PRIOR, FetchOrientation}
 import org.apache.kyuubi.session.Session
+import org.apache.kyuubi.shaded.hive.service.rpc.thrift.{TFetchResultsResp, TGetResultSetMetadataResp, TRowSet}
 
 abstract class JdbcOperation(session: Session) extends AbstractOperation(session) {
 
@@ -101,11 +100,8 @@ abstract class JdbcOperation(session: Session) extends AbstractOperation(session
   override protected def afterRun(): Unit = {}
 
   protected def toTRowSet(taken: Iterator[Row]): TRowSet = {
-    val rowSetHelper = dialect.getRowSetHelper()
-    rowSetHelper.toTRowSet(
-      taken.toList.map(_.values),
-      schema.columns,
-      getProtocolVersion)
+    dialect.getTRowSetGenerator()
+      .toTRowSet(taken.toSeq.map(_.values), schema.columns, getProtocolVersion)
   }
 
   override def getResultSetMetadata: TGetResultSetMetadataResp = {
