@@ -57,9 +57,20 @@ object KyuubiSparkUtil extends Logging {
 
   def engineId: String = globalSparkContext.applicationId
   def engineName: String = globalSparkContext.appName
-  def engineUrl: String = globalSparkContext.getConf.getOption(
-    "spark.org.apache.hadoop.yarn.server.webproxy.amfilter.AmIpFilter.param.PROXY_URI_BASES")
-    .orElse(globalSparkContext.uiWebUrl).getOrElse("")
+  def engineUrl: String = {
+    val sparkConf = globalSparkContext.getConf
+    sparkConf
+      // scalastyle:off line.size.limit
+      // format: off
+      // for Spark 3.5 or before
+      .getOption("spark.org.apache.hadoop.yarn.server.webproxy.amfilter.AmIpFilter.param.PROXY_URI_BASES")
+      // for Spark 4.0 or later, see SPARK-48238
+      .orElse(sparkConf.getOption("spark.org.apache.spark.deploy.yarn.AmIpFilter.param.PROXY_URI_BASES"))
+      // format: on
+      // scalastyle:on line.size.limit
+      .orElse(globalSparkContext.uiWebUrl)
+      .getOrElse("")
+  }
   def deployMode: String = {
     if (globalSparkContext.getConf.getBoolean("spark.kubernetes.submitInDriver", false)) {
       "cluster"
@@ -124,7 +135,7 @@ object KyuubiSparkUtil extends Logging {
     if (SPARK_ENGINE_RUNTIME_VERSION >= "4.0") {
       var uriBuilder = DynMethods.builder("fromUri")
         .impl("jakarta.ws.rs.core.UriBuilder", classOf[URI])
-        .build()
+        .buildStatic()
         .invoke[AnyRef](uri)
 
       uriBuilder = DynMethods.builder("fragment")
@@ -133,13 +144,13 @@ object KyuubiSparkUtil extends Logging {
         .invoke[AnyRef](fragment)
 
       DynMethods.builder("build")
-        .impl("jakarta.ws.rs.core.UriBuilder")
+        .impl("jakarta.ws.rs.core.UriBuilder", classOf[Array[AnyRef]])
         .build(uriBuilder)
-        .invoke[URI]()
+        .invoke[URI](Array.empty[AnyRef])
     } else {
       var uriBuilder = DynMethods.builder("fromUri")
         .impl("javax.ws.rs.core.UriBuilder", classOf[URI])
-        .build()
+        .buildStatic()
         .invoke[AnyRef](uri)
 
       uriBuilder = DynMethods.builder("fragment")
@@ -148,9 +159,9 @@ object KyuubiSparkUtil extends Logging {
         .invoke[AnyRef](fragment)
 
       DynMethods.builder("build")
-        .impl("javax.ws.rs.core.UriBuilder")
+        .impl("javax.ws.rs.core.UriBuilder", classOf[Array[AnyRef]])
         .build(uriBuilder)
-        .invoke[URI]()
+        .invoke[URI](Array.empty[AnyRef])
     }
   }
 }
