@@ -138,7 +138,7 @@ class KyuubiOperationKubernetesClusterClientModeSuite
   extends SparkClientModeOnKubernetesSuiteBase {
   private lazy val k8sOperation: KubernetesApplicationOperation = {
     val operation = new KubernetesApplicationOperation
-    operation.initialize(conf)
+    operation.initialize(conf, None)
     operation
   }
 
@@ -187,7 +187,7 @@ class KyuubiOperationKubernetesClusterClusterModeSuite
   extends SparkClusterModeOnKubernetesSuiteBase {
   private lazy val k8sOperation: KubernetesApplicationOperation = {
     val operation = new KubernetesApplicationOperation
-    operation.initialize(conf)
+    operation.initialize(conf, None)
     operation
   }
 
