@@ -159,6 +159,17 @@ object Utils extends Logging {
     dir
   }
 
+  /**
+   * List the files recursively in a directory.
+   */
+  def listFilesRecursively(file: File): Seq[File] = {
+    if (!file.isDirectory) {
+      file :: Nil
+    } else {
+      file.listFiles().flatMap(listFilesRecursively)
+    }
+  }
+
   /**
    * Copies bytes from an InputStream source to a newly created temporary file
    * created in the directory destination. The temporary file will be created
@@ -318,10 +329,6 @@ object Utils extends Logging {
     }
   }
 
-  def getCodeSourceLocation(clazz: Class[_]): String = {
-    new File(clazz.getProtectionDomain.getCodeSource.getLocation.toURI).getPath
-  }
-
   def fromCommandLineArgs(args: Array[String], conf: KyuubiConf): Unit = {
     require(args.length % 2 == 0, s"Illegal size of arguments.")
     for (i <- args.indices by 2) {
