@@ -92,7 +92,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
   protected def logSessionCountInfo(session: Session, action: String): Unit = {
     info(s"${session.user}'s ${session.getClass.getSimpleName} with" +
       s" ${session.handle}${session.name.map("/" + _).getOrElse("")} is $action," +
-      s" current opening sessions $getOpenSessionCount")
+      s" current opening sessions $getActiveUserSessionCount")
   }
 
   def openSession(
@@ -103,16 +103,16 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
       conf: Map[String, String]): SessionHandle = {
     info(s"Opening session for $user@$ipAddress")
     val session = createSession(protocol, user, password, ipAddress, conf)
+    val handle = session.handle
     try {
-      val handle = session.handle
-      session.open()
       setSession(handle, session)
+      session.open()
       logSessionCountInfo(session, "opened")
       handle
     } catch {
       case e: Exception =>
         try {
-          session.close()
+          closeSession(handle)
         } catch {
           case t: Throwable =>
             warn(s"Error closing session for $user client ip: $ipAddress", t)
@@ -122,11 +122,13 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
   }
 
   def closeSession(sessionHandle: SessionHandle): Unit = {
-    _latestLogoutTime = System.currentTimeMillis()
     val session = handleToSession.remove(sessionHandle)
     if (session == null) {
       throw KyuubiSQLException(s"Invalid $sessionHandle")
     }
+    if (!session.isForAliveProbe) {
+      _latestLogoutTime = System.currentTimeMillis()
+    }
     logSessionCountInfo(session, "closed")
     try {
       session.close()
@@ -159,7 +161,10 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
     handleToSession.put(sessionHandle, session)
   }
 
-  def getOpenSessionCount: Int = handleToSession.size()
+  /**
+   * Get the count of active user sessions, which excludes alive probe sessions.
+   */
+  def getActiveUserSessionCount: Int = handleToSession.values().asScala.count(!_.isForAliveProbe)
 
   def allSessions(): Iterable[Session] = handleToSession.values().asScala
 
@@ -303,7 +308,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
     val checkTask = new Runnable {
       override def run(): Unit = {
-        info(s"Checking sessions timeout, current count: $getOpenSessionCount")
+        info(s"Checking sessions timeout, current count: $getActiveUserSessionCount")
         val current = System.currentTimeMillis
         if (!shutdown) {
           for (session <- handleToSession.values().asScala) {
@@ -341,7 +346,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
       val checkTask = new Runnable {
         override def run(): Unit = {
           if (!shutdown && System.currentTimeMillis() - latestLogoutTime > idleTimeout &&
-            getOpenSessionCount <= 0) {
+            getActiveUserSessionCount <= 0) {
             info(s"Idled for more than $idleTimeout ms, terminating")
             stop()
           }
