@@ -24,8 +24,6 @@ import javax.security.auth.login.Configuration
 import scala.util.Random
 
 import com.google.common.annotations.VisibleForTesting
-import org.apache.curator.framework.{CuratorFramework, CuratorFrameworkFactory}
-import org.apache.curator.retry._
 import org.apache.hadoop.security.UserGroupInformation
 
 import org.apache.kyuubi.Logging
@@ -33,8 +31,10 @@ import org.apache.kyuubi.config.KyuubiConf
 import org.apache.kyuubi.ha.HighAvailabilityConf._
 import org.apache.kyuubi.ha.client.{AuthTypes, RetryPolicies}
 import org.apache.kyuubi.ha.client.RetryPolicies._
-import org.apache.kyuubi.reflection.DynConstructors
+import org.apache.kyuubi.shaded.curator.framework.{CuratorFramework, CuratorFrameworkFactory}
+import org.apache.kyuubi.shaded.curator.retry._
 import org.apache.kyuubi.util.KyuubiHadoopUtils
+import org.apache.kyuubi.util.reflect.DynConstructors
 
 object ZookeeperClientProvider extends Logging {
 
@@ -108,7 +108,11 @@ object ZookeeperClientProvider extends Logging {
           throw new IOException(s"${HA_ZK_AUTH_KEYTAB.key}: $keytab does not exists")
         }
         System.setProperty("zookeeper.sasl.clientconfig", "KyuubiZooKeeperClient")
-        val serverPrincipal = KyuubiHadoopUtils.getServerPrincipal(principal)
+        conf.get(HA_ZK_AUTH_SERVER_PRINCIPAL).foreach { zkServerPrincipal =>
+          // ZOOKEEPER-1467 allows configuring SPN in client
+          System.setProperty("zookeeper.server.principal", zkServerPrincipal)
+        }
+        val zkClientPrincipal = KyuubiHadoopUtils.getServerPrincipal(principal)
         // HDFS-16591 makes breaking change on JaasConfiguration
         val jaasConf = DynConstructors.builder()
           .impl( // Hadoop 3.3.5 and above
@@ -124,7 +128,7 @@ object ZookeeperClientProvider extends Logging {
             classOf[String],
             classOf[String])
           .build[Configuration]()
-          .newInstance("KyuubiZooKeeperClient", serverPrincipal, keytab)
+          .newInstance("KyuubiZooKeeperClient", zkClientPrincipal, keytab)
         Configuration.setConfiguration(jaasConf)
       case _ =>
     }
